@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -54,11 +54,17 @@ class CPageHeader {
 	 */
 	protected $js = [];
 
+	/**
+	* @var {string} sid
+	*/
+	protected $sid;
+
 	/**
 	 * @param string $title
 	 */
 	public function __construct($title = '') {
 		$this->title = CHtml::encode($title);
+		$this->sid = substr(get_cookie(ZBX_SESSION_NAME), 16, 16);
 	}
 
 	/**
@@ -125,12 +131,13 @@ class CPageHeader {
 		<meta name="Author" content="Zabbix SIA" />
 		<title>$this->title</title>
 		<link rel="icon" href="favicon.ico">
-		<link rel="apple-touch-icon-precomposed" sizes="76x76" href="img/apple-touch-icon-76x76-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="120x120" href="img/apple-touch-icon-120x120-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="152x152" href="img/apple-touch-icon-152x152-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="180x180" href="img/apple-touch-icon-180x180-precomposed.png">
-		<link rel="icon" sizes="192x192" href="img/touch-icon-192x192.png">
-		<meta name="msapplication-TileImage" content="img/ms-tile-144x144.png">
+		<link rel="apple-touch-icon-precomposed" sizes="76x76" href="assets/img/apple-touch-icon-76x76-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="120x120" href="assets/img/apple-touch-icon-120x120-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="152x152" href="assets/img/apple-touch-icon-152x152-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="180x180" href="assets/img/apple-touch-icon-180x180-precomposed.png">
+		<link rel="icon" sizes="192x192" href="assets/img/touch-icon-192x192.png">
+		<meta name="csrf-token" content="$this->sid"/>
+		<meta name="msapplication-TileImage" content="assets/img/ms-tile-144x144.png">
 		<meta name="msapplication-TileColor" content="#d40000">
 		<meta name="msapplication-config" content="none"/>
 
