@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -924,11 +924,25 @@ class CConfigurationImport {
 					$item['query_fields'] = $query_fields;
 				}
 
+				if ($item['type'] == ITEM_TYPE_DEPENDENT) {
+					$item['master_itemid'] = $this->referencer->resolveItem($hostId,  $item['master_item']['key']);
+				}
+
+				unset($item['master_item']);
+
 				if ($itemId) {
 					$item['itemid'] = $itemId;
 					$itemsToUpdate[] = $item;
 				}
 				else {
+					/*
+					 * The array key "lld_macro_paths" must exist at this point. It is processed by chain convertion.
+					 * Unlike discoveryrule.update method, discoveryrule.create does not allow "lld_macro_paths"
+					 * to be empty.
+					 */
+					if (!$item['lld_macro_paths']) {
+						unset($item['lld_macro_paths']);
+					}
 					$itemsToCreate[] = $item;
 				}
 			}
@@ -1635,8 +1649,7 @@ class CConfigurationImport {
 	 * @return null
 	 */
 	protected function processImages() {
-		if (CWebUser::$data['type'] != USER_TYPE_SUPER_ADMIN
-				|| (!$this->options['images']['updateExisting'] && !$this->options['images']['createMissing'])) {
+		if (!$this->options['images']['updateExisting'] && !$this->options['images']['createMissing']) {
 			return;
 		}
 
