@@ -23,7 +23,6 @@
  * @property string $groupid
  * @property string $hostid
  * @property string $graphid
- * @property string $druleid
  * @property string $severityMin
  * @property array  $groups
  * @property array  $hosts
@@ -43,7 +42,6 @@ class CPageFilter {
 	const GROUP_LATEST_IDX = 'web.latest.groupid';
 	const HOST_LATEST_IDX = 'web.latest.hostid';
 	const GRAPH_LATEST_IDX = 'web.latest.graphid';
-	const DRULE_LATEST_IDX = 'web.latest.druleid';
 
 	/**
 	 * Configuration options.
@@ -75,9 +73,6 @@ class CPageFilter {
 		// works only if a host is selected or the host filter value is set to 'all'
 		'graphid' => null,
 
-		// works only if a specific host has been selected, will NOT work if the host filter is set to 'all'
-		'druleid' => null,
-
 		// API parameters to be used to retrieve filter objects
 		'groups' => null,
 		'hosts' => null,
@@ -109,7 +104,6 @@ class CPageFilter {
 		'groupids' => null,
 		'hostid' => null,
 		'graphid' => null,
-		'druleid' => null,
 		'severityMin' => null
 	];
 
@@ -143,7 +137,6 @@ class CPageFilter {
 		'groupid' => null,
 		'hostid' => null,
 		'graphid' => null,
-		'druleid' => null,
 		'severityMin' => null
 	];
 
@@ -156,7 +149,6 @@ class CPageFilter {
 		'groupid' => null,
 		'hostid' => null,
 		'graphid' => null,
-		'druleid' => null,
 		'severityMin' => null
 	];
 
@@ -212,7 +204,6 @@ class CPageFilter {
 	 * @param string $options['graphid']
 	 * @param array  $options['triggers']
 	 * @param array  $options['drules']
-	 * @param string $options['druleid']
 	 * @param array  $options['severitiesMin']
 	 * @param int    $options['severitiesMin']['default']
 	 * @param string $options['severitiesMin']['mapId']
@@ -267,11 +258,6 @@ class CPageFilter {
 			$this->_initGraphs($options['graphid'], $options['graphs']);
 		}
 
-		// drules
-		if (isset($options['drules'])) {
-			$this->_initDiscoveries($options['druleid'], $options['drules']);
-		}
-
 		// severities min
 		if (isset($options['severitiesMin'])) {
 			$this->_initSeveritiesMin($options['severityMin'], $options['severitiesMin'], $config);
@@ -295,26 +281,22 @@ class CPageFilter {
 		$this->_profileIdx['groups'] = 'web.'.$profileSection.'.groupid';
 		$this->_profileIdx['hosts'] = 'web.'.$profileSection.'.hostid';
 		$this->_profileIdx['graphs'] = 'web.'.$profileSection.'.graphid';
-		$this->_profileIdx['drules'] = 'web.'.$profileSection.'.druleid';
 		$this->_profileIdx['severityMin'] = 'web.maps.severity_min';
 
 		if ($this->config['select_latest']) {
 			$this->_profileIds['groupid'] = CProfile::get(self::GROUP_LATEST_IDX);
 			$this->_profileIds['hostid'] = CProfile::get(self::HOST_LATEST_IDX);
 			$this->_profileIds['graphid'] = CProfile::get(self::GRAPH_LATEST_IDX);
-			$this->_profileIds['druleid'] = CProfile::get(self::DRULE_LATEST_IDX);
 		}
 		elseif ($this->config['DDReset'] && !$this->config['DDRemember']) {
 			$this->_profileIds['groupid'] = 0;
 			$this->_profileIds['hostid'] = 0;
 			$this->_profileIds['graphid'] = 0;
-			$this->_profileIds['druleid'] = 0;
 		}
 		else {
 			$this->_profileIds['groupid'] = CProfile::get($this->_profileIdx['groups']);
 			$this->_profileIds['hostid'] = CProfile::get($this->_profileIdx['hosts']);
 			$this->_profileIds['graphid'] = CProfile::get($this->_profileIdx['graphs']);
-			$this->_profileIds['druleid'] = CProfile::get($this->_profileIdx['drules']);
 		}
 
 		// minimum severity
@@ -326,7 +308,6 @@ class CPageFilter {
 		$this->_requestIds['groupid'] = isset($options['groupid']) ? $options['groupid'] : null;
 		$this->_requestIds['hostid'] = isset($options['hostid']) ? $options['hostid'] : null;
 		$this->_requestIds['graphid'] = isset($options['graphid']) ? $options['graphid'] : null;
-		$this->_requestIds['druleid'] = isset($options['druleid']) ? $options['druleid'] : null;
 		$this->_requestIds['severityMin'] = isset($options['severityMin']) ? $options['severityMin'] : null;
 	}
 
@@ -372,51 +353,6 @@ class CPageFilter {
 		}
 	}
 
-	/**
-	 * Enriches host groups array by parent groups.
-	 *
-	 * @param array  $groups
-	 * @param string $groups[<groupid>]['groupid']
-	 * @param string $groups[<groupid>]['name']
-	 * @param array  $options                        HostGroup API call parameters.
-	 *
-	 * @return array
-	 */
-	public static function enrichParentGroups(array $groups, array $options = []) {
-		$parents = [];
-		foreach ($groups as $group) {
-			$parent = explode('/', $group['name']);
-			for (array_pop($parent); $parent; array_pop($parent)) {
-				$parents[implode('/', $parent)] = true;
-			}
-		}
-
-		if ($parents) {
-			foreach ($groups as $group) {
-				if (array_key_exists($group['name'], $parents)) {
-					unset($parents[$group['name']]);
-				}
-			}
-		}
-
-		if ($parents) {
-			if (!array_key_exists('output', $options)) {
-				$options['output'] = ['groupid', 'name'];
-			}
-
-			if (!array_key_exists('filter', $options)) {
-				$options['filter'] = [];
-			}
-
-			$options['filter']['name'] = array_keys($parents);
-
-			$options['preservekeys'] = true;
-			$groups += API::HostGroup()->get($options);
-		}
-
-		return $groups;
-	}
-
 	/**
 	 * Load available host groups, choose the selected host group and remember the selection.
 	 * If the host given in the 'hostid' option does not belong to the selected host group, the selected host group
@@ -433,7 +369,7 @@ class CPageFilter {
 		];
 		$options = zbx_array_merge($defaultOptions, $options);
 		$this->data['groups'] = API::HostGroup()->get($options);
-		$this->data['groups'] = self::enrichParentGroups($this->data['groups']);
+		$this->data['groups'] = enrichParentGroups($this->data['groups']);
 
 		CArrayHelper::sort($this->data['groups'], ['name']);
 
@@ -683,47 +619,6 @@ class CPageFilter {
 		$this->ids['graphid'] = $graphid;
 	}
 
-	/**
-	 * Load the available network discovery rules, choose the selected rule and remember the selection.
-	 *
-	 * @param int   $druleid
-	 * @param array $options
-	 */
-	private function _initDiscoveries($druleid, array $options) {
-		$def_options = [
-			'output' => API_OUTPUT_EXTEND
-		];
-		$options = zbx_array_merge($def_options, $options);
-		$drules = API::DRule()->get($options);
-		order_result($drules, 'name');
-
-		$this->data['drules'] = [];
-		foreach ($drules as $drule) {
-			$this->data['drules'][$drule['druleid']] = $drule;
-		}
-
-		if (is_null($druleid)) {
-			$druleid = $this->_profileIds['druleid'];
-		}
-
-		if ((!isset($this->data['drules'][$druleid]) && $druleid > 0) || is_null($druleid)) {
-			if ($this->config['DDFirst'] == ZBX_DROPDOWN_FIRST_NONE) {
-				$druleid = 0;
-			}
-			elseif (is_null($this->_requestIds['druleid']) || $this->_requestIds['druleid'] > 0) {
-				$druleids = array_keys($this->data['drules']);
-				$druleid = empty($druleids) ? 0 : reset($druleids);
-			}
-		}
-
-		CProfile::update($this->_profileIdx['drules'], $druleid, PROFILE_TYPE_ID);
-		CProfile::update(self::DRULE_LATEST_IDX, $druleid, PROFILE_TYPE_ID);
-
-		$this->isSelected['drulesSelected'] = ($this->config['DDFirst'] == ZBX_DROPDOWN_FIRST_ALL && !empty($this->data['drules'])) || $druleid > 0;
-		$this->isSelected['drulesAll'] = $this->config['DDFirst'] == ZBX_DROPDOWN_FIRST_ALL && !empty($this->data['drules']) && $druleid == 0;
-		$this->ids['druleid'] = $druleid;
-	}
-
 	/**
 	 * Initialize minimum trigger severities.
 	 *
@@ -830,19 +725,6 @@ class CPageFilter {
 		return $graphComboBox;
 	}
 
-	/**
-	 * Get discovery rules combobox with selected item.
-	 *
-	 * @return CComboBox
-	 */
-	public function getDiscoveryCB() {
-		$items = [];
-		foreach ($this->drules as $id => $drule) {
-			$items[$id] = $drule['name'];
-		}
-		return $this->_getCB('druleid', $this->druleid, $items, ['objectName' => 'discovery']);
-	}
-
 	/**
 	 * Get minimum trigger severities combobox with selected item.
 	 *
