@@ -37,20 +37,19 @@ $widget = (new CWidget())
 		))->setAttribute('aria-label', _('Content controls'))
 	);
 
-if (!empty($this->data['hostid'])) {
-	$widget->addItem(get_header_host_table('items', $this->data['hostid']));
+if ($data['hostid'] != 0) {
+	$widget->addItem(get_header_host_table('items', $data['hostid']));
 }
-$widget->addItem($this->data['flicker']);
+$widget->addItem($data['main_filter']);
 
 // create form
 $itemForm = (new CForm())->setName('items');
-if (!empty($this->data['hostid'])) {
-	$itemForm->addVar('hostid', $this->data['hostid']);
+$itemForm->addVar('checkbox_hash', $data['checkbox_hash']);
+if (!empty($data['hostid'])) {
+	$itemForm->addVar('hostid', $data['hostid']);
 }
 
-$url = (new CUrl('items.php'))
-	->setArgument('hostid', $data['hostid'])
-	->getUrl();
+$url = (new CUrl('items.php'))->getUrl();
 
 // create table
 $itemTable = (new CTableInfo())
@@ -59,7 +58,7 @@ $itemTable = (new CTableInfo())
 			(new CCheckBox('all_items'))->onClick("checkAll('".$itemForm->getName()."', 'all_items', 'group_itemid');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
 		_('Wizard'),
-		empty($this->data['filter_hostid']) ? _('Host') : null,
+		($data['hostid'] == 0) ? _('Host') : null,
 		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder'], $url),
 		_('Triggers'),
 		make_sorting_header(_('Key'), 'key_', $data['sort'], $data['sortorder'], $url),
@@ -72,13 +71,9 @@ $itemTable = (new CTableInfo())
 		_('Info')
 	]);
 
-if (!$this->data['filterSet']) {
-	$itemTable->setNoDataMessage(_('Specify some filter condition to see the items.'));
-}
-
 $current_time = time();
 
-$this->data['itemTriggers'] = CMacrosResolverHelper::resolveTriggerExpressions($this->data['itemTriggers'], [
+$data['itemTriggers'] = CMacrosResolverHelper::resolveTriggerExpressions($data['itemTriggers'], [
 	'html' => true,
 	'sources' => ['expression', 'recovery_expression']
 ]);
@@ -145,7 +140,7 @@ foreach ($data['items'] as $item) {
 	$triggerHintTable = (new CTableInfo())->setHeader([_('Severity'), _('Name'), _('Expression'), _('Status')]);
 
 	foreach ($item['triggers'] as $num => &$trigger) {
-		$trigger = $this->data['itemTriggers'][$trigger['triggerid']];
+		$trigger = $data['itemTriggers'][$trigger['triggerid']];
 
 		$trigger_description = [];
 		$trigger_description[] = makeTriggerTemplatePrefix($trigger['triggerid'], $data['trigger_parent_templates'],
@@ -179,7 +174,7 @@ foreach ($data['items'] as $item) {
 		}
 
 		$triggerHintTable->addRow([
-			getSeverityCell($trigger['priority'], $this->data['config']),
+			getSeverityCell($trigger['priority'], $data['config']),
 			$trigger_description,
 			$expression,
 			(new CSpan(triggerIndicator($trigger['status'], $trigger['state'])))
@@ -199,9 +194,18 @@ foreach ($data['items'] as $item) {
 		$triggerInfo = '';
 	}
 
+	$wizard = (new CSpan(
+		(new CButton(null))
+			->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
+			->setMenuPopup(CMenuPopupHelper::getItem($item['itemid']))
+	))->addClass(ZBX_STYLE_REL_CONTAINER);
+
 	if (in_array($item['value_type'], [ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_TEXT])) {
 		$item['trends'] = '';
 	}
+	else if ($item['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
+		$wizard = '';
+	}
 
 	// Hide zeros for trapper, SNMP trap and dependent items.
 	if ($item['type'] == ITEM_TYPE_TRAPPER || $item['type'] == ITEM_TYPE_SNMPTRAP
@@ -212,16 +216,10 @@ foreach ($data['items'] as $item) {
 		$item['delay'] = $update_interval_parser->getDelay();
 	}
 
-	$wizard = (new CSpan(
-		(new CButton(null))
-			->addClass(ZBX_STYLE_ICON_WZRD_ACTION)
-			->setMenuPopup(CMenuPopupHelper::getItem($item['itemid']))
-	))->addClass(ZBX_STYLE_REL_CONTAINER);
-
 	$itemTable->addRow([
 		new CCheckBox('group_itemid['.$item['itemid'].']', $item['itemid']),
 		$wizard,
-		empty($this->data['filter_hostid']) ? $item['host'] : null,
+		($data['hostid'] == 0) ? $item['host'] : null,
 		$description,
 		$triggerInfo,
 		CHtml::encode($item['key_']),
@@ -235,12 +233,10 @@ foreach ($data['items'] as $item) {
 	]);
 }
 
-zbx_add_post_js('cookie.prefix = "'.$this->data['hostid'].'";');
-
 // append table to form
 $itemForm->addItem([
 	$itemTable,
-	$this->data['paging'],
+	$data['paging'],
 	new CActionButtonList('action', 'group_itemid',
 		[
 			'item.massenable' => ['name' => _('Enable'), 'confirm' => _('Enable selected items?')],
@@ -253,7 +249,7 @@ $itemForm->addItem([
 			'item.massupdateform' => ['name' => _('Mass update')],
 			'item.massdelete' => ['name' => _('Delete'), 'confirm' => _('Delete selected items?')]
 		],
-		$this->data['hostid']
+		$data['checkbox_hash']
 	)
 ]);
 
