@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,37 +21,31 @@
 
 require_once dirname(__FILE__).'/include/config.inc.php';
 require_once dirname(__FILE__).'/include/triggers.inc.php';
-require_once dirname(__FILE__).'/include/hostgroups.inc.php';
 
 $page['title'] = _('100 busiest triggers');
 $page['file'] = 'toptriggers.php';
-$page['scripts'] = ['multiselect.js', 'class.calendar.js'];
+$page['scripts'] = ['multiselect.js', 'class.calendar.js', 'gtlc.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 //	VAR					TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'groupids' =>				[T_ZBX_INT,	O_OPT,	P_SYS,			DB_ID,	null],
-	'hostids' =>				[T_ZBX_INT,	O_OPT,	P_SYS,			DB_ID,	null],
-	'severities'=>				[T_ZBX_INT,	O_OPT,	P_SYS,			null,	null],
-	'filter_from' =>			[T_ZBX_STR,	O_OPT,	P_UNSET_EMPTY,	null,	null],
-	'filter_till' =>			[T_ZBX_STR,	O_OPT,	P_UNSET_EMPTY,	null,	null],
-	'filter_rst' =>				[T_ZBX_STR,	O_OPT,	P_SYS,			null,	null],
-	'filter_set' =>				[T_ZBX_STR,	O_OPT,	P_SYS,			null,	null]
+	'groupids' =>	[T_ZBX_INT,			O_OPT,	P_SYS,	DB_ID,	null],
+	'hostids' =>	[T_ZBX_INT,			O_OPT,	P_SYS,	DB_ID,	null],
+	'severities' =>	[T_ZBX_INT,			O_OPT,	P_SYS,	null,	null],
+	'from' =>		[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,	null,	null],
+	'to' =>			[T_ZBX_RANGE_TIME,	O_OPT,	P_SYS,	null,	null],
+	'filter_rst' =>	[T_ZBX_STR,			O_OPT,	P_SYS,	null,	null],
+	'filter_set' =>	[T_ZBX_STR,			O_OPT,	P_SYS,	null,	null]
 ];
 check_fields($fields);
+validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
 
 $data['config'] = select_config();
 
 /*
  * Filter
  */
-$today = mktime(0, 0, 0, date('n'), date('j'), date('Y'));
-$tomorrow = $today + SEC_PER_DAY;
-
-$timeFrom = hasRequest('filter_from') ? zbxDateToTime(getRequest('filter_from')) : $today;
-$timeTill = hasRequest('filter_till') ? zbxDateToTime(getRequest('filter_till')) : $tomorrow;
-
 if (hasRequest('filter_set')) {
 	// prepare severity array
 	$severities = hasRequest('severities') ? array_keys(getRequest('severities')) : [];
@@ -59,19 +53,23 @@ if (hasRequest('filter_set')) {
 	CProfile::updateArray('web.toptriggers.filter.severities', $severities, PROFILE_TYPE_STR);
 	CProfile::updateArray('web.toptriggers.filter.groupids', getRequest('groupids', []), PROFILE_TYPE_STR);
 	CProfile::updateArray('web.toptriggers.filter.hostids', getRequest('hostids', []), PROFILE_TYPE_STR);
-	CProfile::update('web.toptriggers.filter.from', $timeFrom, PROFILE_TYPE_STR);
-	CProfile::update('web.toptriggers.filter.till', $timeTill, PROFILE_TYPE_STR);
 }
 elseif (hasRequest('filter_rst')) {
 	DBstart();
 	CProfile::deleteIdx('web.toptriggers.filter.severities');
 	CProfile::deleteIdx('web.toptriggers.filter.groupids');
 	CProfile::deleteIdx('web.toptriggers.filter.hostids');
-	CProfile::delete('web.toptriggers.filter.from');
-	CProfile::delete('web.toptriggers.filter.till');
 	DBend();
 }
 
+$timeselector_options = [
+	'profileIdx' => 'web.toptriggers.filter',
+	'profileIdx2' => 0,
+	'from' => getRequest('from'),
+	'to' => getRequest('to')
+];
+updateTimeSelectorPeriod($timeselector_options);
+
 if (!hasRequest('filter_set')) {
 	for ($severity = TRIGGER_SEVERITY_NOT_CLASSIFIED; $severity < TRIGGER_SEVERITY_COUNT; $severity++) {
 		$defaultSeverities[$severity] = $severity;
@@ -83,11 +81,10 @@ else {
 
 $data['filter'] = [
 	'severities' => CProfile::getArray('web.toptriggers.filter.severities', $defaultSeverities),
-	'filter_from' => CProfile::get('web.toptriggers.filter.from', $today),
-	'filter_till' => CProfile::get('web.toptriggers.filter.till', $tomorrow)
+	'timeline' => getTimeSelectorPeriod($timeselector_options),
+	'active_tab' => CProfile::get('web.toptriggers.filter.active', 1)
 ];
 
-
 // multiselect host groups
 $data['multiSelectHostGroupData'] = [];
 $groupids = CProfile::getArray('web.toptriggers.filter.groupids', []);
@@ -123,8 +120,8 @@ $sql = 'SELECT e.objectid,count(distinct e.eventid) AS cnt_event'.
 		' WHERE t.triggerid=e.objectid'.
 			' AND e.source='.EVENT_SOURCE_TRIGGERS.
 			' AND e.object='.EVENT_OBJECT_TRIGGER.
-			' AND e.clock>='.zbx_dbstr($data['filter']['filter_from']).
-			' AND e.clock<='.zbx_dbstr($data['filter']['filter_till']).
+			' AND e.clock>='.zbx_dbstr($data['filter']['timeline']['from_ts']).
+			' AND e.clock<='.zbx_dbstr($data['filter']['timeline']['to_ts']).
 			' AND '.dbConditionInt('t.priority', $data['filter']['severities']);
 
 if ($hostids) {
@@ -174,16 +171,13 @@ while ($row = DBfetch($result)) {
 }
 
 $data['triggers'] = API::Trigger()->get([
-	'output' => ['triggerid', 'description', 'expression', 'priority', 'flags', 'url', 'lastchange'],
-	'selectItems' => ['itemid', 'hostid', 'name', 'key_', 'value_type'],
+	'output' => ['triggerid', 'description', 'expression', 'priority', 'lastchange'],
 	'selectHosts' => ['hostid', 'status', 'name'],
 	'triggerids' => array_keys($triggersEventCount),
 	'expandDescription' => true,
 	'preservekeys' => true
 ]);
 
-$data['triggers'] = CMacrosResolverHelper::resolveTriggerUrls($data['triggers']);
-
 $trigger_hostids = [];
 
 foreach ($data['triggers'] as $triggerId => $trigger) {
@@ -200,14 +194,10 @@ CArrayHelper::sort($data['triggers'], [
 
 $data['hosts'] = API::Host()->get([
 	'output' => ['hostid', 'status'],
-	'selectGraphs' => API_OUTPUT_COUNT,
-	'selectScreens' => API_OUTPUT_COUNT,
 	'hostids' => $trigger_hostids,
 	'preservekeys' => true
 ]);
 
-$data['scripts'] = API::Script()->getScriptsByHosts($trigger_hostids);
-
 // render view
 $historyView = new CView('reports.toptriggers', $data);
 $historyView->render();
